searchData={"items":[{"type":"module","title":"Torchx","doc":"Bindings and Nx integration for [PyTorch](https://pytorch.org/).\n\nTorchx provides an Nx backend through `Torchx.Backend`, which\nallows for integration with both the CPU and GPU functionality\nthat PyTorch provides. To enable Torchx as the default backend\nyou can add the following line to your desired config environment (`config/config.exs`,\n`config/test.exs`, etc):\n\n    import Config\n    config :nx, :default_backend, Torchx.Backend\n\nThis will ensure that by default all tensors are created PyTorch tensors.\nIt's important to keep in mind that the default device is the CPU. If you\nwish to allocated tensors to the GPU by default, you can pass the `:device`\noption to the config line, as follows:\n\n    import Config\n    config :nx, :default_backend, {Torchx.Backend, device: :cuda}\n\nThe `device_available?/1` function can be used to determine whether\n`:cuda` is available. If you have CUDA installed but it doesn't show\nas available, check out the _Installation_ README section.","ref":"Torchx.html"},{"type":"module","title":"Types - Torchx","doc":"Torchx implements specific names for PyTorch types, which have Nx\ncounterparts as in the following table:\n\n  Nx Type    |  Torchx Type    | Description\n ----------- | --------------- | --------------------------------------------------------\n `{:u, 8}`   | `:byte`           | Unsigned 8-bit integer\n `{:s, 8}`   | `:char`           | Signed 8-bit integer\n `{:s, 16}`  | `:short`          | Signed 16-bit integer\n `{:s, 32}`  | `:int`            | Signed 32-bit integer\n `{:s, 64}`  | `:long`           | Signed 64-bit integer\n `{:bf, 16}` | `:brain`          | 16-bit brain floating-point number\n `{:f, 16}`  | `:half`           | 16-bit floating-point number\n `{:f, 32}`  | `:float`          | 32-bit floating-point number\n `{:f, 64}`  | `:double`         | 64-bit floating-point number\n `{:c, 64}`  | `:complex`        | 64-bit complex number, with two 32-bit float components\n `{:c, 128}` | `:complex_double` | 128-bit complex number, with two 64-bit float components","ref":"Torchx.html#module-types"},{"type":"module","title":"Devices - Torchx","doc":"PyTorch implements a variety of devices, which can be seen below.\n\n  * `:cpu`\n  * `:cuda`\n  * `:mkldnn`\n  * `:opengl`\n  * `:opencl`\n  * `:ideep`\n  * `:hip`\n  * `:fpga`\n  * `:msnpu`\n  * `:xla`\n  * `:vulkan`\n  * `:metal`\n  * `:xpu`\n  * `:mps`","ref":"Torchx.html#module-devices"},{"type":"function","title":"Torchx.abs/1","doc":"","ref":"Torchx.html#abs/1"},{"type":"function","title":"Torchx.acos/1","doc":"","ref":"Torchx.html#acos/1"},{"type":"function","title":"Torchx.acosh/1","doc":"","ref":"Torchx.html#acosh/1"},{"type":"function","title":"Torchx.add/2","doc":"","ref":"Torchx.html#add/2"},{"type":"function","title":"Torchx.all/1","doc":"","ref":"Torchx.html#all/1"},{"type":"function","title":"Torchx.all/3","doc":"","ref":"Torchx.html#all/3"},{"type":"function","title":"Torchx.all_close/5","doc":"","ref":"Torchx.html#all_close/5"},{"type":"function","title":"Torchx.amax/3","doc":"","ref":"Torchx.html#amax/3"},{"type":"function","title":"Torchx.amin/3","doc":"","ref":"Torchx.html#amin/3"},{"type":"function","title":"Torchx.any/1","doc":"","ref":"Torchx.html#any/1"},{"type":"function","title":"Torchx.any/3","doc":"","ref":"Torchx.html#any/3"},{"type":"function","title":"Torchx.arange/5","doc":"","ref":"Torchx.html#arange/5"},{"type":"function","title":"Torchx.arange/6","doc":"","ref":"Torchx.html#arange/6"},{"type":"function","title":"Torchx.argmax/3","doc":"","ref":"Torchx.html#argmax/3"},{"type":"function","title":"Torchx.argmin/3","doc":"","ref":"Torchx.html#argmin/3"},{"type":"function","title":"Torchx.argsort/3","doc":"","ref":"Torchx.html#argsort/3"},{"type":"function","title":"Torchx.as_strided/4","doc":"","ref":"Torchx.html#as_strided/4"},{"type":"function","title":"Torchx.asin/1","doc":"","ref":"Torchx.html#asin/1"},{"type":"function","title":"Torchx.asinh/1","doc":"","ref":"Torchx.html#asinh/1"},{"type":"function","title":"Torchx.atan2/2","doc":"","ref":"Torchx.html#atan2/2"},{"type":"function","title":"Torchx.atan/1","doc":"","ref":"Torchx.html#atan/1"},{"type":"function","title":"Torchx.atanh/1","doc":"","ref":"Torchx.html#atanh/1"},{"type":"function","title":"Torchx.bitwise_and/2","doc":"","ref":"Torchx.html#bitwise_and/2"},{"type":"function","title":"Torchx.bitwise_not/1","doc":"","ref":"Torchx.html#bitwise_not/1"},{"type":"function","title":"Torchx.bitwise_or/2","doc":"","ref":"Torchx.html#bitwise_or/2"},{"type":"function","title":"Torchx.bitwise_xor/2","doc":"","ref":"Torchx.html#bitwise_xor/2"},{"type":"function","title":"Torchx.broadcast_to/2","doc":"","ref":"Torchx.html#broadcast_to/2"},{"type":"function","title":"Torchx.cbrt/1","doc":"","ref":"Torchx.html#cbrt/1"},{"type":"function","title":"Torchx.ceil/1","doc":"","ref":"Torchx.html#ceil/1"},{"type":"function","title":"Torchx.cholesky/1","doc":"","ref":"Torchx.html#cholesky/1"},{"type":"function","title":"Torchx.cholesky/2","doc":"","ref":"Torchx.html#cholesky/2"},{"type":"function","title":"Torchx.clip/3","doc":"","ref":"Torchx.html#clip/3"},{"type":"function","title":"Torchx.concatenate/2","doc":"","ref":"Torchx.html#concatenate/2"},{"type":"function","title":"Torchx.conjugate/1","doc":"","ref":"Torchx.html#conjugate/1"},{"type":"function","title":"Torchx.conv/7","doc":"","ref":"Torchx.html#conv/7"},{"type":"function","title":"Torchx.cos/1","doc":"","ref":"Torchx.html#cos/1"},{"type":"function","title":"Torchx.cosh/1","doc":"","ref":"Torchx.html#cosh/1"},{"type":"function","title":"Torchx.cumulative_max/2","doc":"","ref":"Torchx.html#cumulative_max/2"},{"type":"function","title":"Torchx.cumulative_min/2","doc":"","ref":"Torchx.html#cumulative_min/2"},{"type":"function","title":"Torchx.cumulative_product/2","doc":"","ref":"Torchx.html#cumulative_product/2"},{"type":"function","title":"Torchx.cumulative_sum/2","doc":"","ref":"Torchx.html#cumulative_sum/2"},{"type":"function","title":"Torchx.default_device/0","doc":"Returns the default device.\n\nHere is the priority in the order of availability:\n\n* `:cuda`\n* `:cpu`\n\nThe default can also be set (albeit not recommended)\nvia the application environment by setting the\n`:default_device` option under the `:torchx` application.","ref":"Torchx.html#default_device/0"},{"type":"function","title":"Torchx.delete_tensor/1","doc":"","ref":"Torchx.html#delete_tensor/1"},{"type":"function","title":"Torchx.determinant/1","doc":"","ref":"Torchx.html#determinant/1"},{"type":"function","title":"Torchx.device_available?/1","doc":"Check if device of the given type is available for Torchx.\n\nYou can currently check the availability of:\n\n* `:cuda`\n* `:mps`\n* `:cpu`","ref":"Torchx.html#device_available?/1"},{"type":"function","title":"Torchx.device_count/1","doc":"Return devices quantity for the given device type.\n\nYou can check the device count of `:cuda` for now.","ref":"Torchx.html#device_count/1"},{"type":"function","title":"Torchx.divide/2","doc":"","ref":"Torchx.html#divide/2"},{"type":"function","title":"Torchx.eigh/1","doc":"","ref":"Torchx.html#eigh/1"},{"type":"function","title":"Torchx.equal/2","doc":"","ref":"Torchx.html#equal/2"},{"type":"function","title":"Torchx.erf/1","doc":"","ref":"Torchx.html#erf/1"},{"type":"function","title":"Torchx.erf_inv/1","doc":"","ref":"Torchx.html#erf_inv/1"},{"type":"function","title":"Torchx.erfc/1","doc":"","ref":"Torchx.html#erfc/1"},{"type":"function","title":"Torchx.exp/1","doc":"","ref":"Torchx.html#exp/1"},{"type":"function","title":"Torchx.expm1/1","doc":"","ref":"Torchx.html#expm1/1"},{"type":"function","title":"Torchx.eye/3","doc":"","ref":"Torchx.html#eye/3"},{"type":"function","title":"Torchx.eye/4","doc":"","ref":"Torchx.html#eye/4"},{"type":"function","title":"Torchx.fft/2","doc":"","ref":"Torchx.html#fft/2"},{"type":"function","title":"Torchx.flip/2","doc":"","ref":"Torchx.html#flip/2"},{"type":"function","title":"Torchx.floor/1","doc":"","ref":"Torchx.html#floor/1"},{"type":"function","title":"Torchx.fmod/2","doc":"","ref":"Torchx.html#fmod/2"},{"type":"function","title":"Torchx.from_blob/4","doc":"","ref":"Torchx.html#from_blob/4"},{"type":"function","title":"Torchx.from_nx/1","doc":"Gets a Torchx tensor from a Nx tensor.","ref":"Torchx.html#from_nx/1"},{"type":"function","title":"Torchx.full/4","doc":"","ref":"Torchx.html#full/4"},{"type":"function","title":"Torchx.gather/3","doc":"","ref":"Torchx.html#gather/3"},{"type":"function","title":"Torchx.greater/2","doc":"","ref":"Torchx.html#greater/2"},{"type":"function","title":"Torchx.greater_equal/2","doc":"","ref":"Torchx.html#greater_equal/2"},{"type":"function","title":"Torchx.ifft/2","doc":"","ref":"Torchx.html#ifft/2"},{"type":"function","title":"Torchx.index/2","doc":"","ref":"Torchx.html#index/2"},{"type":"function","title":"Torchx.index_put/4","doc":"","ref":"Torchx.html#index_put/4"},{"type":"function","title":"Torchx.is_infinity/1","doc":"","ref":"Torchx.html#is_infinity/1"},{"type":"function","title":"Torchx.is_nan/1","doc":"","ref":"Torchx.html#is_nan/1"},{"type":"macro","title":"Torchx.is_tensor/2","doc":"","ref":"Torchx.html#is_tensor/2"},{"type":"function","title":"Torchx.item/1","doc":"","ref":"Torchx.html#item/1"},{"type":"function","title":"Torchx.left_shift/2","doc":"","ref":"Torchx.html#left_shift/2"},{"type":"function","title":"Torchx.less/2","doc":"","ref":"Torchx.html#less/2"},{"type":"function","title":"Torchx.less_equal/2","doc":"","ref":"Torchx.html#less_equal/2"},{"type":"function","title":"Torchx.log1p/1","doc":"","ref":"Torchx.html#log1p/1"},{"type":"function","title":"Torchx.log/1","doc":"","ref":"Torchx.html#log/1"},{"type":"function","title":"Torchx.logical_and/2","doc":"","ref":"Torchx.html#logical_and/2"},{"type":"function","title":"Torchx.logical_not/1","doc":"","ref":"Torchx.html#logical_not/1"},{"type":"function","title":"Torchx.logical_or/2","doc":"","ref":"Torchx.html#logical_or/2"},{"type":"function","title":"Torchx.logical_xor/2","doc":"","ref":"Torchx.html#logical_xor/2"},{"type":"function","title":"Torchx.lu/1","doc":"","ref":"Torchx.html#lu/1"},{"type":"function","title":"Torchx.matmul/2","doc":"","ref":"Torchx.html#matmul/2"},{"type":"function","title":"Torchx.max/2","doc":"","ref":"Torchx.html#max/2"},{"type":"function","title":"Torchx.max_pool_3d/5","doc":"","ref":"Torchx.html#max_pool_3d/5"},{"type":"function","title":"Torchx.min/2","doc":"","ref":"Torchx.html#min/2"},{"type":"function","title":"Torchx.multiply/2","doc":"","ref":"Torchx.html#multiply/2"},{"type":"function","title":"Torchx.narrow/4","doc":"","ref":"Torchx.html#narrow/4"},{"type":"function","title":"Torchx.nbytes/1","doc":"","ref":"Torchx.html#nbytes/1"},{"type":"function","title":"Torchx.negate/1","doc":"","ref":"Torchx.html#negate/1"},{"type":"function","title":"Torchx.normal/5","doc":"","ref":"Torchx.html#normal/5"},{"type":"function","title":"Torchx.not_equal/2","doc":"","ref":"Torchx.html#not_equal/2"},{"type":"function","title":"Torchx.ones/3","doc":"","ref":"Torchx.html#ones/3"},{"type":"function","title":"Torchx.pad/3","doc":"","ref":"Torchx.html#pad/3"},{"type":"function","title":"Torchx.permute/2","doc":"","ref":"Torchx.html#permute/2"},{"type":"function","title":"Torchx.pow/2","doc":"","ref":"Torchx.html#pow/2"},{"type":"function","title":"Torchx.product/1","doc":"","ref":"Torchx.html#product/1"},{"type":"function","title":"Torchx.product/3","doc":"","ref":"Torchx.html#product/3"},{"type":"function","title":"Torchx.put/3","doc":"","ref":"Torchx.html#put/3"},{"type":"function","title":"Torchx.qr/1","doc":"","ref":"Torchx.html#qr/1"},{"type":"function","title":"Torchx.qr/2","doc":"","ref":"Torchx.html#qr/2"},{"type":"function","title":"Torchx.quotient/2","doc":"","ref":"Torchx.html#quotient/2"},{"type":"function","title":"Torchx.rand/5","doc":"","ref":"Torchx.html#rand/5"},{"type":"function","title":"Torchx.randint/5","doc":"","ref":"Torchx.html#randint/5"},{"type":"function","title":"Torchx.remainder/2","doc":"","ref":"Torchx.html#remainder/2"},{"type":"function","title":"Torchx.reshape/2","doc":"","ref":"Torchx.html#reshape/2"},{"type":"function","title":"Torchx.right_shift/2","doc":"","ref":"Torchx.html#right_shift/2"},{"type":"function","title":"Torchx.round/1","doc":"","ref":"Torchx.html#round/1"},{"type":"function","title":"Torchx.rsqrt/1","doc":"","ref":"Torchx.html#rsqrt/1"},{"type":"function","title":"Torchx.scalar_tensor/3","doc":"","ref":"Torchx.html#scalar_tensor/3"},{"type":"function","title":"Torchx.scalar_type/1","doc":"","ref":"Torchx.html#scalar_type/1"},{"type":"function","title":"Torchx.shape/1","doc":"","ref":"Torchx.html#shape/1"},{"type":"function","title":"Torchx.sigmoid/1","doc":"","ref":"Torchx.html#sigmoid/1"},{"type":"function","title":"Torchx.sign/1","doc":"","ref":"Torchx.html#sign/1"},{"type":"function","title":"Torchx.sin/1","doc":"","ref":"Torchx.html#sin/1"},{"type":"function","title":"Torchx.sinh/1","doc":"","ref":"Torchx.html#sinh/1"},{"type":"function","title":"Torchx.solve/2","doc":"","ref":"Torchx.html#solve/2"},{"type":"function","title":"Torchx.sort/3","doc":"","ref":"Torchx.html#sort/3"},{"type":"function","title":"Torchx.split/2","doc":"","ref":"Torchx.html#split/2"},{"type":"function","title":"Torchx.sqrt/1","doc":"","ref":"Torchx.html#sqrt/1"},{"type":"function","title":"Torchx.squeeze/1","doc":"","ref":"Torchx.html#squeeze/1"},{"type":"function","title":"Torchx.squeeze/2","doc":"","ref":"Torchx.html#squeeze/2"},{"type":"function","title":"Torchx.subtract/2","doc":"","ref":"Torchx.html#subtract/2"},{"type":"function","title":"Torchx.sum/3","doc":"","ref":"Torchx.html#sum/3"},{"type":"function","title":"Torchx.svd/1","doc":"","ref":"Torchx.html#svd/1"},{"type":"function","title":"Torchx.svd/2","doc":"","ref":"Torchx.html#svd/2"},{"type":"function","title":"Torchx.tan/1","doc":"","ref":"Torchx.html#tan/1"},{"type":"function","title":"Torchx.tanh/1","doc":"","ref":"Torchx.html#tanh/1"},{"type":"function","title":"Torchx.tensordot/4","doc":"","ref":"Torchx.html#tensordot/4"},{"type":"function","title":"Torchx.tensordot/6","doc":"","ref":"Torchx.html#tensordot/6"},{"type":"function","title":"Torchx.to_blob/1","doc":"","ref":"Torchx.html#to_blob/1"},{"type":"function","title":"Torchx.to_blob/2","doc":"","ref":"Torchx.html#to_blob/2"},{"type":"function","title":"Torchx.to_device/2","doc":"","ref":"Torchx.html#to_device/2"},{"type":"function","title":"Torchx.to_nx/1","doc":"Converts a Torchx tensor to a Nx tensor.","ref":"Torchx.html#to_nx/1"},{"type":"function","title":"Torchx.to_type/2","doc":"","ref":"Torchx.html#to_type/2"},{"type":"function","title":"Torchx.top_k/2","doc":"","ref":"Torchx.html#top_k/2"},{"type":"function","title":"Torchx.transpose/3","doc":"","ref":"Torchx.html#transpose/3"},{"type":"function","title":"Torchx.triangular_solve/4","doc":"","ref":"Torchx.html#triangular_solve/4"},{"type":"function","title":"Torchx.unfold/4","doc":"","ref":"Torchx.html#unfold/4"},{"type":"function","title":"Torchx.view_as_real/1","doc":"","ref":"Torchx.html#view_as_real/1"},{"type":"function","title":"Torchx.where/3","doc":"","ref":"Torchx.html#where/3"},{"type":"module","title":"Torchx.Backend","doc":"An opaque backend Nx backend with bindings to libtorch/Pytorch.\n\nTorchx behaviour that is different from BinaryBackend:\n\n  1. Torchx emulates the u16/u32/u64 unsigned integers using signed integers.\n     In practice this means u64 actually overflows at u32. When accessing the\n     underlying tensor, you will get signed integers back.\n\n      iex> t = Nx.Constants.max_finite({:u, 32})\n      #Nx.Tensor \n      iex> t |> Torchx.from_nx() |> Torchx.to_nx()\n      #Nx.Tensor \n\n  2. Torchx rounds half-to-even, while Elixir rounds half-away-from-zero.\n     So in Elixir `round(0.5) == 1.0` while in Torchx `round(0.5) == 0.0`.\n\n  3. `Nx.as_type/2` converts non-finite values such as infinity becomes the\n     maximum value for a type, negative infinity becomes the minimum value,\n     and nan becomes zero. `Torchx` behaviour is type dependent with no clear\n     rule across types.","ref":"Torchx.Backend.html"},{"type":"module","title":"Options - Torchx.Backend","doc":"* `:device` - Defaults to `Torchx.default_device/0`. An atom representing the\n    device for the allocation of a given tensor. Valid values can be seen at the\n    main `Torchx` docs.","ref":"Torchx.Backend.html#module-options"},{"type":"function","title":"Torchx.Backend.steps_to_strides/2","doc":"","ref":"Torchx.Backend.html#steps_to_strides/2"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.6.4 (2023-11-13) - Changelog","doc":"* Update to latest Nx\n  * Improve the `:axes` option in `gather`, `indexed_add`, and `indexed_put`","ref":"changelog.html#v0-6-4-2023-11-13"},{"type":"extras","title":"v0.6.3 (2023-11-09) - Changelog","doc":"* Update to latest Nx","ref":"changelog.html#v0-6-3-2023-11-09"},{"type":"extras","title":"v0.6.1 (2023-09-12) - Changelog","doc":"* Update to latest Nx","ref":"changelog.html#v0-6-1-2023-09-12"},{"type":"extras","title":"v0.6.0 (2023-08-15) - Changelog","doc":"* Update to latest Nx","ref":"changelog.html#v0-6-0-2023-08-15"},{"type":"extras","title":"v0.5.3 (2023-04-14) - Changelog","doc":"* No changes","ref":"changelog.html#v0-5-3-2023-04-14"},{"type":"extras","title":"v0.5.2 (2023-03-21) - Changelog","doc":"* No changes","ref":"changelog.html#v0-5-2-2023-03-21"},{"type":"extras","title":"v0.5.1 (2023-02-18) - Changelog","doc":"* Support `top_k`","ref":"changelog.html#v0-5-1-2023-02-18"},{"type":"extras","title":"v0.5.0 (2023-02-10) - Changelog","doc":"* Use relative symlinks on compilation whenever possible","ref":"changelog.html#v0-5-0-2023-02-10"},{"type":"extras","title":"v0.4.2 (2023-01-13) - Changelog","doc":"#","ref":"changelog.html#v0-4-2-2023-01-13"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Cache LibTorch downloads across repositories","ref":"changelog.html#enhancements"},{"type":"extras","title":"v0.4.1 (2022-12-07) - Changelog","doc":"#","ref":"changelog.html#v0-4-1-2022-12-07"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Require Nx ~> 0.4.1","ref":"changelog.html#enhancements"},{"type":"extras","title":"v0.4.0 (2022-10-25) - Changelog","doc":"#","ref":"changelog.html#v0-4-0-2022-10-25"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Support `bitcast`\n  * Support window dilations\n  * Support conv input dilations\n  * Support for Apple Silicon\n  * Emulate u16/u32/u64 types\n\n#","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* Fix dot product with multiple batches","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"v0.3.0 (2022-08-13) - Changelog","doc":"#","ref":"changelog.html#v0-3-0-2022-08-13"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Support new callbacks added in Nx v0.3.0","ref":"changelog.html#enhancements"},{"type":"extras","title":"v0.2.0 (2022-04-28) - Changelog","doc":"First release.","ref":"changelog.html#v0-2-0-2022-04-28"}],"content_type":"text/markdown"}